==> breeze-5.0.95.tar.xz: breeze-5.0.95/kstyle/animations/breezeanimationdata.cpp <==
/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/

#include "breezeanimationdata.h"
#include "breezeanimationdata.moc"

namespace Breeze
{

    qreal AnimationData::OpacityInvalid = -1;
    int AnimationData::_steps = 0;

    //_________________________________________________________________________________
    void AnimationData::setupAnimation( const Animation::Pointer& animation, const QByteArray& property )
    {

        // setup animation
        animation.data()->setStartValue( 0.0 );
        animation.data()->setEndValue( 1.0 );
        animation.data()->setTargetObject( this );
        animation.data()->setPropertyName( property );

    }

}

==> breeze-5.2.2.tar.xz: breeze-5.2.2/kstyle/animations/breezeanimationdata.cpp <==
/*************************************************************************
 * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
 *                                                                       *
 * This program is free software; you can redistribute it and/or modify  *
 * it under the terms of the GNU General Public License as published by  *
 * the Free Software Foundation; either version 2 of the License, or     *
 * (at your option) any later version.                                   *
 *                                                                       *
 * This program is distributed in the hope that it will be useful,       *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 * GNU General Public License for more details.                          *
 *                                                                       *
 * You should have received a copy of the GNU General Public License     *
 * along with this program; if not, write to the                         *
 * Free Software Foundation, Inc.,                                       *
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 *************************************************************************/

#include "breezeanimationdata.h"
#include "breezeanimationdata.moc"

namespace Breeze
{

    const qreal AnimationData::OpacityInvalid = -1;
    int AnimationData::_steps = 0;

    //_________________________________________________________________________________
    void AnimationData::setupAnimation( const Animation::Pointer& animation, const QByteArray& property )
    {

        // setup animation
        animation.data()->setStartValue( 0.0 );
        animation.data()->setEndValue( 1.0 );
        animation.data()->setTargetObject( this );
        animation.data()->setPropertyName( property );

    }

}
